/*
 * faaconv.h - header file for all faaconv modules
 *
 * Copyright (C) 1998, John C. Peterson <mailto:jaypee@netcom.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License,
 * version 2. A copy is included in this distribution in the file
 * named "LICENSE".
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License, version 2, for more details.
 *
 * $Id: faaconv.h,v 1.1 1998/05/05 06:45:21 jcp Exp $
 *
 */

/* include header files */

#include "apt.h"
#include "fix.h"
#include "ils.h"
#include "nav.h"
#include "rwy.h"
#include "field_model.h"

/* define macros */

#define VERSION		"0.1"

#define ENV_MODEL_DIR	"FAACONV_LIB"

#ifndef DEF_MODEL_DIR
#define DEF_MODEL_DIR	"/usr/share/avdbtools"
#endif

#define SPRINTF(p,fmt,arg) p += sprintf(p,fmt,arg)

#define FEET2KM(feet)	((feet)*0.0003048)
#define DEG2RAD(deg)	((deg)*(M_PI/180.0L))
#define RAD2DEG(rad)	((rad)*(180.0L/M_PI))
#define ROUND(x)	((int)(0.5+(x)))

#define BUF_LEN 2048

#ifdef TRUE
#undef TRUE
#endif

#ifdef FALSE
#undef FALSE
#endif

#define TRUE	((bool_t)1)
#define FALSE	((bool_t)0)

/* declare data types */

typedef int bool_t;

typedef bool_t (*write_rec_t)(char **tok_str);

typedef enum {
  DB_APT,
  DB_FIX,
  DB_ILS,
  DB_NAV,
  DB_RWY
} db_t;

/* global variables */

extern FILE *fpinput;
extern FILE *fpoutput;
extern char *inputfile;
extern char *outputfile;

extern db_t db_type;
extern bool_t option_k;
extern write_rec_t write_rec;

extern bool_t model_required;
extern bool_t model_priority;
extern char *model_directory;
extern char *model_filename;
extern char *model_fullname;
extern field_model_t model;

/* function prototypes */

/* utils.c */
extern char *strcap( char *str );
extern char *strkid( char *ident );

/* write_generic.c */
extern bool_t write_generic( char **tok_str );

/* write_icao.c */
extern bool_t write_icao( char **tok_str );

/* write_nav.c */
extern bool_t write_nav( char **tok_str );

